pub fn externally_checked_ext<T: Config>()Expand description
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::externally_checked_ext.
pub fn externally_checked_ext<T: Config>()This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::externally_checked_ext.